@@ -18,6 +18,7 @@
 
 import Paths_hopenpgp_tools (version)
 import Codec.Encryption.OpenPGP.Fingerprint (eightOctetKeyID)
+import Codec.Encryption.OpenPGP.KeyInfo (keySize, pkalgoAbbrev)
 import Codec.Encryption.OpenPGP.Types
 import Control.Applicative ((<$>),(<*>), optional)
 import Control.Lens ((^.))
@@ -51,13 +52,9 @@ grabMatchingKeys fp eok = do
 
 showKey :: TK -> IO ()
 showKey key = putStrLn . unlines . execWriter $ do
-    tell [ "pub   " ++ show (keysize (key^.tkPKP^.pubkey)) ++ (take 1 $ show $ key^.tkPKP^.pkalgo) ++ "/0x" ++ (show . eightOctetKeyID $ key^.tkPKP ) ]
+    tell [ "pub   " ++ show (keySize (key^.tkPKP^.pubkey)) ++ (pkalgoAbbrev $ key^.tkPKP^.pkalgo) ++ "/0x" ++ (show . eightOctetKeyID $ key^.tkPKP ) ]
     tell $ map (\(x,_) -> "uid                            " ++ x) (key^.tkUIDs)
-    tell $ map (\((PublicSubkeyPkt x),_,_) -> "sub   " ++ show (keysize (x^.pubkey)) ++ (take 1 $ show $ x^.pkalgo) ++ "/0x" ++ (show . eightOctetKeyID $ x)) (key^.tkSubs)
-    where
-        keysize (RSAPubKey x) = RSA.public_size x * 8
-        keysize (DSAPubKey x) = bitcount . DSA.params_q . DSA.public_params $ x -- should go into lib
-	bitcount = (*8) . length . unfoldr (\x -> if x == 0 then Nothing else Just (True, x `shiftR` 8))
+    tell $ map (\((PublicSubkeyPkt x),_,_) -> "sub   " ++ show (keySize (x^.pubkey)) ++ (pkalgoAbbrev $ x^.pkalgo) ++ "/0x" ++ (show . eightOctetKeyID $ x)) (key^.tkSubs)
 
 data Options = Options {
     keyring :: String
