@@ -18,6 +18,7 @@
 
 import Paths_hopenpgp_tools (version)
 import Codec.Encryption.OpenPGP.Fingerprint (fingerprint, eightOctetKeyID)
+import Codec.Encryption.OpenPGP.KeyInfo (keySize)
 import Codec.Encryption.OpenPGP.Types
 import Control.Applicative ((<$>),(<*>), optional)
 import Control.Lens ((^.), (^?!), ix)
@@ -65,11 +66,9 @@ checkKey key = putStrLn . unlines . execWriter $ do
     tell $ concatMap (\(x,ys) -> ("  " ++ x ++ ":"):((map (("    "++) . show . kets) . filter (\x -> sigissuer x == Issuer (eoki key)) $ ys))) (key^.tkUIDs)
     tell $ concatMap (\(_,ys) -> ("  <uat>:"):((map (("    "++) . show . kets) . filter (\x -> sigissuer x == Issuer (eoki key)) $ ys))) (key^.tkUAts)
     where
-        rsadsa2 = (key^.tkPKP^.pkalgo == RSA && rsasize >= 2048) ||
-                  (key^.tkPKP^.pkalgo == DSA && dsasize >= 2048)
-        rsasize = (\(RSAPubKey x) -> RSA.public_size x) (key^.tkPKP^.pubkey) * 8
-        dsasize = (\(DSAPubKey x) -> bitcount . DSA.params_q . DSA.public_params $ x) (key^.tkPKP^.pubkey) -- should go into lib
-	bitcount = (*8) . length . unfoldr (\x -> if x == 0 then Nothing else Just (True, x `shiftR` 8))
+        rsadsa2 = (key^.tkPKP^.pkalgo == RSA && keysize >= 2048) ||
+                  (key^.tkPKP^.pkalgo == DSA && keysize >= 2048)
+        keysize = keySize (key^.tkPKP^.pubkey)
 	sigissuer (SigV3 _ _ _ _ _ _ _) = OtherSigSub 666 B.empty -- this is dumb
 	sigissuer (SigV4 _ _ _ _ xs _ _) = xs^?!ix 0^.sspPayload -- this is a horrible stack of stupid assumptions
 	sigissuer (SigVOther _ _) = error "We're in the future."
