@@ -41,7 +41,7 @@ import System.IO (stdin, stderr, hPutStrLn, hFlush, hSetBuffering, BufferMode(..
 
 import Options.Applicative.Builder (command, help, idm, info, long, metavar, nullOption, reader, progDesc, strOption, subparser, ParseError(..))
 import Options.Applicative.Extra (execParser)
-import Options.Applicative.Types (Parser)
+import Options.Applicative.Types (Parser, ReadM(..))
 
 data Command = DumpC | DeArmorC | ArmorC ArmoringOptions
 
@@ -71,12 +71,14 @@ doArmor ArmoringOptions{..} = do
     let a = Armor armortype ([("Version", "hot " ++ showVersion version)] ++ maybe [] (\x -> [("Comment", x)]) comment ) (BL.fromChunks m)
     BL.putStr $ AA.encodeLazy [a]
 
-armorTypeReader :: String -> Either ParseError ArmorType
-armorTypeReader "message" = Right ArmorMessage	 
-armorTypeReader "pubkeyblock" = Right ArmorPublicKeyBlock	 
-armorTypeReader "privkeyblock" = Right ArmorPrivateKeyBlock	 
-armorTypeReader "signature" = Right ArmorSignature
-armorTypeReader _ = Left (ErrorMsg "unknown armor type")
+armorTypeReader :: String -> ReadM ArmorType
+armorTypeReader = ReadM . armorTypeReader'
+    where
+        armorTypeReader' "message" = Right ArmorMessage	 
+        armorTypeReader' "pubkeyblock" = Right ArmorPublicKeyBlock	 
+        armorTypeReader' "privkeyblock" = Right ArmorPrivateKeyBlock	 
+        armorTypeReader' "signature" = Right ArmorSignature
+        armorTypeReader' _ = Left (ErrorMsg "unknown armor type")
 
 aoP :: Parser ArmoringOptions
 aoP = ArmoringOptions
